#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-HsgJLwRO1g121BxZ8w2K0S
key:                  coinbase-pro-0.9.3.2-HsgJLwRO1g121BxZ8w2K0S
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  0d1de42b327daeb573a17dea8122a898
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-HsgJLwRO1g121BxZ8w2K0S
depends:
    HsOpenSSL-0.11.7.9-CF1kN3lvWonBsdVjRLSL2Q
    aeson-2.2.1.0-6KokJsif6KIKBUd4sU6s2R
    aeson-casing-0.2.0.0-OJHgxXnZVk2XRYqbSq7R8
    async-2.2.5-G9iNhoihA4w9hFmxVZ2fQd base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LPKlrACUhq4IQiGZrRBhiY exceptions-0.10.7
    http-api-data-0.6.1-2u1nI3Ho6HrHl3IrnujjeS
    http-client-0.7.19-4TXhbqeieFKC3v25ZPjlVk
    http-client-tls-0.3.6.4-3jHGgIt5pGkAObeGksQPdq
    http-streams-0.8.9.9-DGOjBgOnWka7uIKQ6JVhDW
    http-types-0.12.4-AN10jFjv98J7LJR84l19K7
    io-streams-1.5.2.2-8iUJKs0mmp5BQuju20xxbM
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-AiHJr4xbLJq8z0BHBbc6nI
    servant-0.20.3.0-KqQGkHo1dPP1hy3PWDZ7pQ
    servant-client-0.20.3.0-37rCtD4qpKADOMhruqniYx
    servant-client-core-0.20.3.0-ArblkzZWHFyJ7T15YGaSef
    tasty-1.5.2-5pBTNMwGPzK105AVUIyB3L
    tasty-hunit-0.10.2-3nLTEcTMv1dEMF9ig7B9MU text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-GjqW9hZTAbd7kASgoUXUWJ
    unordered-containers-0.2.20.1-LXAzHO8zZLp8w9V0PnyDcb
    uuid-1.3.16-7DgGWDyj8BqJIp6JY8kGq9
    vector-0.13.2.0-91lzNiZgjgOBDn02pUIYXJ
    websockets-0.12.7.3-38xbA3Wl8oz6uoPQk3tHNn
    wuss-2.0.1.6-6NSANbZWn18I9Pow0BnLFc

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

